==> aws-java-sdk-1.3.1-sources.jar: com/amazonaws/services/cloudfront/model/transform/TrustedSignersStaxUnmarshaller.java <==
/*
 * Copyright 2010-2012 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 * 
 *  http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package com.amazonaws.services.cloudfront.model.transform;

import java.util.Map;
import java.util.Map.Entry;

import javax.xml.stream.events.XMLEvent;

import com.amazonaws.services.cloudfront.model.*;
import com.amazonaws.transform.Unmarshaller;
import com.amazonaws.transform.MapEntry;
import com.amazonaws.transform.StaxUnmarshallerContext;
import com.amazonaws.transform.SimpleTypeStaxUnmarshallers.*;


/**
 * Trusted Signers StAX Unmarshaller
 */
public class TrustedSignersStaxUnmarshaller implements Unmarshaller<TrustedSigners, StaxUnmarshallerContext> {

    public TrustedSigners unmarshall(StaxUnmarshallerContext context) throws Exception {
        TrustedSigners trustedSigners = new TrustedSigners();
        int originalDepth = context.getCurrentDepth();
        int targetDepth = originalDepth + 1;
        if (context.isStartOfDocument()) targetDepth += 1;
        

        while (true) {
            XMLEvent xmlEvent = context.nextEvent();
            if (xmlEvent.isEndDocument()) return trustedSigners;

            if (xmlEvent.isAttribute() || xmlEvent.isStartElement()) {
                if (context.testExpression("Self", targetDepth)) {
                    trustedSigners.setSelf(StringStaxUnmarshaller.getInstance().unmarshall(context));
                    continue;
                }
                if (context.testExpression("AwsAccountNumber", targetDepth)) {
                    trustedSigners.getAwsAccountNumbers().add(StringStaxUnmarshaller.getInstance().unmarshall(context));
                    continue;
                }
            } else if (xmlEvent.isEndElement()) {
                if (context.getCurrentDepth() < originalDepth) {
                    return trustedSigners;
                }
            }
        }
    }

    private static TrustedSignersStaxUnmarshaller instance;
    public static TrustedSignersStaxUnmarshaller getInstance() {
        if (instance == null) instance = new TrustedSignersStaxUnmarshaller();
        return instance;
    }
}

==> aws-java-sdk-1.3.26-sources.jar: com/amazonaws/services/cloudfront/model/transform/TrustedSignersStaxUnmarshaller.java <==
/*
 * Copyright 2010-2012 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 * 
 *  http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package com.amazonaws.services.cloudfront.model.transform;

import java.util.Map;
import java.util.Map.Entry;

import javax.xml.stream.events.XMLEvent;

import com.amazonaws.services.cloudfront.model.*;
import com.amazonaws.transform.Unmarshaller;
import com.amazonaws.transform.MapEntry;
import com.amazonaws.transform.StaxUnmarshallerContext;
import com.amazonaws.transform.SimpleTypeStaxUnmarshallers.*;


/**
 * Trusted Signers StAX Unmarshaller
 */
public class TrustedSignersStaxUnmarshaller implements Unmarshaller<TrustedSigners, StaxUnmarshallerContext> {

    public TrustedSigners unmarshall(StaxUnmarshallerContext context) throws Exception {
        TrustedSigners trustedSigners = new TrustedSigners();
        int originalDepth = context.getCurrentDepth();
        int targetDepth = originalDepth + 1;
        if (context.isStartOfDocument()) targetDepth += 1;
        

        while (true) {
            XMLEvent xmlEvent = context.nextEvent();
            if (xmlEvent.isEndDocument()) return trustedSigners;

            if (xmlEvent.isAttribute() || xmlEvent.isStartElement()) {
                if (context.testExpression("Enabled", targetDepth)) {
                    trustedSigners.setEnabled(BooleanStaxUnmarshaller.getInstance().unmarshall(context));
                    continue;
                }
                if (context.testExpression("Quantity", targetDepth)) {
                    trustedSigners.setQuantity(IntegerStaxUnmarshaller.getInstance().unmarshall(context));
                    continue;
                }
                if (context.testExpression("Items/AwsAccountNumber", targetDepth)) {
                    trustedSigners.getItems().add(StringStaxUnmarshaller.getInstance().unmarshall(context));
                    continue;
                }
            } else if (xmlEvent.isEndElement()) {
                if (context.getCurrentDepth() < originalDepth) {
                    return trustedSigners;
                }
            }
        }
    }

    private static TrustedSignersStaxUnmarshaller instance;
    public static TrustedSignersStaxUnmarshaller getInstance() {
        if (instance == null) instance = new TrustedSignersStaxUnmarshaller();
        return instance;
    }
}
